// Copyright 2013 Canonical Ltd.
// Licensed under the AGPLv3, see LICENCE file for details.

package envcmd

var (
	GetCurrentEnvironmentFilePath = getCurrentEnvironmentFilePath
	GetConfigStore                = &getConfigStore
	EndpointRefresher             = &endpointRefresher
)
